```
Usage: vcd vapp add-disk [OPTIONS] <name> <vm-name> <size>

Options:
  -s, --storage-profile <storage-profile>
                                  Name of the storage profile for the new disk
  -h, --help                      Show this message and exit.

```
